<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns="http://docbook.org/ns/docbook"
  xmlns:d="http://docbook.org/ns/docbook" version="1.0">
  <xsl:import href="../docbook-xsl/fo/docbook.xsl"/>
  <!-- specify output so viewable -->
  <xsl:output method="xml" indent="yes"/>
  <xsl:param name="use.extensions">0</xsl:param>
  <xsl:param name="fop1.extensions">1</xsl:param>
  <!-- recommended setting when using fop -->
  <xsl:param name="body.start.indent">0in</xsl:param>
  <xsl:param name="hyphenate">true</xsl:param>
  <!-- same as HTML -->
  <xsl:param name="toc.section.depth">2</xsl:param>
  <xsl:param name="insert.xref.page.number">0</xsl:param>
  <!-- make links identifiable -->
  <xsl:attribute-set name="xref.properties">
    <xsl:attribute name="color">blue</xsl:attribute>
  </xsl:attribute-set>
  <!-- default body font -->
  <xsl:param name="body.font.master">12</xsl:param>
  <!-- turn off -->
  <xsl:param name="section.autolabel">0</xsl:param>
  <!-- set draft mode parameters here -->
  <xsl:param name="draft.mode">no</xsl:param>
  <xsl:param name="draft.watermark.image">images/draft.png</xsl:param>
  <xsl:param name="show.comments">0</xsl:param>
  <!--
    Style admonitions
  -->
  <xsl:param name="admon.textlabel">0</xsl:param>
  <xsl:param name="admon.graphics">1</xsl:param>
  <xsl:param name="admon.graphics.path">images/</xsl:param>
  <xsl:attribute-set name="graphical.admonition.properties">
    <xsl:attribute name="margin">.05in</xsl:attribute>
    <xsl:attribute name="padding">.05in</xsl:attribute>
    <xsl:attribute name="padding-top">.1in</xsl:attribute>
    <xsl:attribute name="padding-right">.1in</xsl:attribute>
    <xsl:attribute name="font-style">italic</xsl:attribute>
    <xsl:attribute name="border-top">.5pt solid grey</xsl:attribute>
    <xsl:attribute name="border-bottom">1pt solid grey</xsl:attribute>
    <!-- customize bg colour for admons -->
    <xsl:attribute name="background-color">
      <xsl:choose>
        <xsl:when test="self::d:note">#edf9ff</xsl:when>
        <xsl:when test="self::d:warning">#fff1dc</xsl:when>
      </xsl:choose>
    </xsl:attribute>
  </xsl:attribute-set>
  <!-- Table properties -->
  <!-- links in tables are a mess -->
  <xsl:param name="ulink.show" select="0"/>
  <xsl:attribute-set name="table.cell.padding">
    <xsl:attribute name="padding-start">3px</xsl:attribute>
    <xsl:attribute name="padding-end">2px</xsl:attribute>
    <xsl:attribute name="padding-top">2px</xsl:attribute>
    <xsl:attribute name="padding-bottom">2px</xsl:attribute>
  </xsl:attribute-set>
  <!-- style for table header -->
  <xsl:template name="table.row.properties">
    <xsl:if test="ancestor::d:thead">
      <xsl:attribute name="font-weight">bold</xsl:attribute>
      <xsl:attribute name="background-color">#EEEEEE</xsl:attribute>
    </xsl:if>
  </xsl:template>
  <!-- callouts -->
  <!-- spacing around callouts -->
  <xsl:attribute-set name="callout.properties">
    <xsl:attribute name="margin">0.1in</xsl:attribute>
  </xsl:attribute-set>
  <!-- callouts -->
  <xsl:param name="callout.unicode">1</xsl:param>
  <xsl:param name="callout.graphics">0</xsl:param>
  <!--
    verbatim properties
  -->
  <xsl:param name="shade.verbatim" select="1"/>
  <xsl:attribute-set name="shade.verbatim.style">
    <xsl:attribute name="border-top">0.5pt solid black</xsl:attribute>
    <xsl:attribute name="border-left">0.5pt solid black</xsl:attribute>
    <xsl:attribute name="border-bottom">1pt solid black</xsl:attribute>
    <xsl:attribute name="border-right">1pt solid black</xsl:attribute>
    <xsl:attribute name="background-color">#EEE</xsl:attribute>
    <xsl:attribute name="padding">0.1in</xsl:attribute>
    <!-- no padding at top so can start on line below tag -->
    <xsl:attribute name="padding-top">0in</xsl:attribute>
    <xsl:attribute name="margin">0.1in</xsl:attribute>
  </xsl:attribute-set>
  <xsl:attribute-set name="monospace.properties">
    <xsl:attribute name="font-size">10pt</xsl:attribute>
  </xsl:attribute-set>
  <xsl:attribute-set name="monospace.verbatim.properties"
    use-attribute-sets="verbatim.properties monospace.properties">
    <xsl:attribute name="font-size">0.7em</xsl:attribute>
  </xsl:attribute-set>
  <!-- glossary related -->
  <xsl:param name="glossentry.show.acronym">1</xsl:param>
  <xsl:param name="glossterm.auto.link">1</xsl:param>
  <xsl:param name="glossary.sort">1</xsl:param>
  <!-- Advanced customizations follow  -->
  <!-- add logo, use corpauthor if applicable -->
  <xsl:template match="d:author" mode="book.titlepage.verso.mode">
    <fo:block space-before="1em" space-after="1em">
      <fo:external-graphic src="url(images/logo.png)"/>
    </fo:block>
    <xsl:apply-templates mode="titlepage.mode"/>
  </xsl:template>
  <!-- 
    Change title properties
  -->
  <!-- increase font size for book title -->
  <xsl:template match="d:title" mode="book.titlepage.recto.auto.mode">
    <fo:block xmlns:fo="http://www.w3.org/1999/XSL/Format"
      xsl:use-attribute-sets="book.titlepage.recto.style" text-align="left"
      font-size="32pt" space-before="18.6624pt" font-weight="bold"
      font-family="{$title.fontset}">
      <xsl:call-template name="division.title">
        <xsl:with-param name="node" select="ancestor-or-self::d:book[1]"/>
      </xsl:call-template>
    </fo:block>
  </xsl:template>
  <!-- increase font size for chapter title -->
  <xsl:template match="d:title" mode="chapter.titlepage.recto.auto.mode">
    <fo:block xmlns:fo="http://www.w3.org/1999/XSL/Format"
      xsl:use-attribute-sets="chapter.titlepage.recto.style" font-size="22pt"
      font-weight="bold" space-after=".4in">
      <xsl:call-template name="component.title">
        <xsl:with-param name="node" select="ancestor-or-self::d:chapter[1]"/>
      </xsl:call-template>
    </fo:block>
  </xsl:template>
  <!-- increase font size for appendix title -->
  <xsl:template match="d:title" mode="appendix.titlepage.recto.auto.mode">
    <fo:block xmlns:fo="http://www.w3.org/1999/XSL/Format"
      xsl:use-attribute-sets="appendix.titlepage.recto.style"
      margin-left="{$title.margin.left}" font-size="22pt" space-after=".4in"
      font-weight="bold" font-family="{$title.fontset}">
      <xsl:call-template name="component.title">
        <xsl:with-param name="node" select="ancestor-or-self::d:appendix[1]"/>
      </xsl:call-template>
    </fo:block>
  </xsl:template>
</xsl:stylesheet>