<?php
/**
* Format JSON uniformly. If it is already formatted,
* remove the formatting and do it again.
* Fix up the Doctype afterwards.
**/
$source = $argv[1];
$d = new DOMDocument();
$d->load($source);
//find root element for doctype 
$root = $d->documentElement->tagName;
$xpath = new DOMXPath($d);
//find all JSON
$xpath->registerNamespace('d', 'http://docbook.org/ns/docbook');
//find all json screen tags
$elements = $xpath->query("//d:screen[@language='json']");
for ($i = 0; $i < $elements->length; $i++) {
  $element = $elements->item($i);  
  $content =  $element->textContent;
  //remove newlines, any existing formatting
  //this is not strictly necessary, pretty_print is
  //pretty versatile
  $content = trim(preg_replace('/\s+/', ' ', $content));
  $newcontent = "";
  $newcontent = pretty_print($content);
  //assign data to text node
  if ($newcontent != "") {
    $newcontent = "\n" . $newcontent . "\n";
    $element->removeChild($element->firstChild);
    $element->appendChild(new DOMText($newcontent));
  }
}

$d->save($source);
//fix up doctype
//remove embedded entities
$doctype = "<!DOCTYPE " . $root . "
[
  <!ENTITY % all.entities SYSTEM \"all-entities.ent\">
  %all.entities;
]>";
$contents = file_get_contents($source);
$contents = preg_replace("/<!DOCTYPE[[:alnum:]\s\[\]\n<!?%-_\"' #]+?]>/", $doctype, $contents, 1);

file_put_contents($source, $contents);
/**
* Format a JSON string for pretty printing
* adapted from
*http://stackoverflow.com/questions/6054033/pretty-printing-json-with-php
*/
function pretty_print($json){
  $result = '';
  $level = 0;
  $prev_char = '';
  $tab = '  ';
  $in_quotes = false;
  $ends_line_level = NULL;
  $json_length = strlen( $json );

  for( $i = 0; $i < $json_length; $i++ ) {
    $char = $json[$i];
    $new_line_level = NULL;
    $post = "";
    if( $ends_line_level !== NULL ) {
      $new_line_level = $ends_line_level;
      $ends_line_level = NULL;
    }
    if( $char === '"' && $prev_char != '\\' ) {
      $in_quotes = !$in_quotes;
    } else if( ! $in_quotes ) {
      switch( $char ) {
        case '}': case ']':
          $level--;
          $ends_line_level = NULL;
          $new_line_level = $level;
          break;

        case '{': case '[':
          $level++;
        case ',':
          $ends_line_level = $level;
          break;

        case ':':
          $post = " ";
          break;

        case " ": case "\t": case "\n": case "\r":
          $char = "";
          $ends_line_level = $new_line_level;
          $new_line_level = NULL;
          break;
      }
    }
    if( $new_line_level !== NULL ) {
      $result .= "\n".str_repeat( $tab, $new_line_level );
    }
    $result .= $char.$post;
    $prev_char = $char;
  }
  return $result;
}
?>

