<?php
/**
* Prepare for processing by pandoc
* Do this before converting to 4.5
* 1) Convert xrefs to links.
* 2) Combine title and subtitle
* 3) Fix callouts
**/

$d = new DOMDocument();
//$d->resolveExternals = true;
//$d->substituteEntities = true;
$source = $argv[1];
//make dest a temp file
$dest = "tmp.xml";
echo "Processing " . $source . "\n\n";
$d->load($source, LIBXML_NOXMLDECL);
//find all xref tags
fixXrefs($d);
//add text for links with only an href
linkText($d);
makeTitle($d);
callouts($d);
$d->save($dest);
//end main

/*
* Converts xrefs to links
*/
function fixXrefs($d){
  //array of xref linkends
  $xrefs = Array();
  //array of text associated with those linkends
  //key is the linkend and value is the associated text
  $titles = Array();
  $xpath = new DOMXPath($d);
  $xpath->registerNamespace('d', 'http://docbook.org/ns/docbook');
  $elements = $xpath->query("//d:xref");
  for ($i = 0; $i < $elements->length; $i++) {
    $element = $elements->item($i);
    //get the linkend and add to an array
    //only add if it isn't in the array
    if (!in_array($element->getAttribute('linkend'), $xrefs)){
      $xrefs[] = $element->getAttribute('linkend');
    }
  }
  //loop through the array and get a title
  //to go with the xref
  foreach($xrefs as $x) {
    //get element associated with this id
    $element = $d->getElementById($x); 
    //what kind of tag is it
    switch ($element->tagName) {
  
      case 'bridgehead':
        //only one element
        $text = $element->nodeValue;
        $titles[$x] = $text; 
        break;
        
      case 'co':  
        //assume there is a <callout> with arearefs attribute
        //set to this id
        $callouts = $xpath->query("//d:*[@arearefs='$x']");
        $text = countListitems($callouts->item(0));
        $titles[$x] = $text; 
        break;
      
      case 'glossentry':
        $title = $element->getElementsByTagName ('glossterm');
        $text = $title->item(0)->textContent;
        $titles[$x] = $text; 
        break;
        
      case 'refentry':
        $title = $element->getElementsByTagName ('refentrytitle');
        $text = $title->item(0)->textContent;
        $titles[$x] = $text; 
        break;
        
      case 'varlistentry':
        $title = $element->getElementsByTagName ('term');
        $text = $title->item(0)->textContent;
        $titles[$x] = $text; 
        break;
         
      case 'listitem':
        //parent is an orderedlist, get the list item number
        $title = countListitems($element);
        $titles[$x] = $title;
        break;
        
      default: // this should cover sections, chapters,
        // figures, examples, notes, sidebars--anything with a title
        $title = $element->getElementsByTagName ('title');
        $text = $title->item(0)->textContent;
        $titles[$x] = $text; 
    }
  }
  //now change xrefs to links
  //do an xpath query for xrefs again
  $xpath = new DOMXPath($d);
  $xpath->registerNamespace('d', 'http://docbook.org/ns/docbook');
  //find all xref tags
  $elements = $xpath->query("//d:xref");
  foreach($elements as $node) {
    //create new link node
    //convert to a link, use title as text
    $link =  $d->createElement('link');
    $link->setAttribute('linkend', $node->getAttribute('linkend'));
    //use linkend as key to value in $titles
    $value = $titles[$node->getAttribute('linkend')];
    $link->appendChild(new DOMText($value));
    //there is only one child
    $parent = $node->parentNode;
    $parent->replaceChild($link, $node );
  }
}

/**
* Determine which node it is
* so we have a number for the title
*/
function countListitems($element){
  //get parent in order to determine
  //where this node occurs
  $parent = $element->parentNode;
  //should be an orderedlist
  $x = 0;
  foreach($parent->childNodes as $n)  {
    if ($n->nodeName == 'listitem' ||
       $n->nodeName == 'callout' ){
      //increment counter
      $x ++;
      // found the right node
      if ($n->isSameNode ($element)){
        break;
      }
    }
  }
  return $x;
} 
/**
* Find links with no text node:
* (<link xl:href="url"/> and add
* text.
*/
function linkText($d) {
  $xpath = new DOMXPath($d);
  $xpath->registerNamespace('d', 'http://docbook.org/ns/docbook');
  $elements = $xpath->query("//d:link");
  foreach ($elements as $e){
    if(!$e->hasChildNodes()){
      //add href text as child text node
      $text = $e->getAttribute('xl:href');  
      $text_node = $d->createTextNode($text);
      $e->appendChild($text_node);
    }
  }
}
/**
* Associate a number with the co tag
*/
function callouts($d){
  //first associate a number with each callout
  //in a calloutlist
  $lists = $d->getElementsByTagName ('calloutlist');
  $arr_counts = array();
  $count = 0;
  for ($i = 0; $i < $lists->length; $i++) {
    $e = $lists->item($i);
    //find number of children
    foreach($e->childNodes as $node) {
      if ($node->nodeName == 'callout'){
        $count ++;
      }
    }
    //track where breaks occur
    $arr_counts[] = $count;
  }
  $elements = $d->getElementsByTagName('co');
  $number = 0;
  $i = 0;  // which element of the array
  $subscript = 0; // which co tag (in the document)
  while ($i < count($arr_counts)) {
    for (; $subscript < $arr_counts[$i]; $subscript++) {
      $number ++;
      $text = NULL;
      $text = $d->createTextNode (" " . $number);
      $element = $elements->item($subscript);
      //can't delete nodes while iterating 
      //so set a text value to the node
      //and later remove the <co> tag (via XSL)
      //but leave the text in place.
      $element->appendChild($text);
    }
    //reset, a new calloutlist
    $number = 0;
    $i++;
  }
  return;
}
/**
* Combine title and subtitle
*/
function makeTitle($d){
  //match any title
  $subtitle_text = "";
  $xpath = new DOMXPath($d);
  $xpath->registerNamespace('d', 'http://docbook.org/ns/docbook');
  $nodes = $xpath->query("//*[d:subtitle]");
  //check for subtitle
  foreach($nodes as $node) {
    //get subtitle text
    foreach($node->childNodes as $n){
      if ($n->nodeName == "subtitle"){ 
        $subtitle_text = $n->nodeValue;
        $n->parentNode->removeChild($n);
      }
    }
    //node must have a title if it has a subtitle
    foreach($node->childNodes as $n){
      if ($n->nodeName == "title"){      
        $n->nodeValue = $n->nodeValue . ":\n" . $subtitle_text;
        break;
      }
    }
  }
}
?>

